# -*- coding: utf-8 -*-
# Copyright (c) 2018-2021, earthobservations developers.
# Distributed under the MIT License. See LICENSE for more info.
from wetterdienst.provider.dwd.metadata.column_names import DwdColumns
from wetterdienst.provider.dwd.mosmix.metadata.parameter import DwdMosmixParameter

DATE_FIELDS_REGULAR = DwdColumns.DATETIME.value

INTEGER_PARAMETERS = {
    DwdMosmixParameter.LARGE.WIND_DIRECTION.value,
    DwdMosmixParameter.LARGE.WEATHER_LAST_6H.value,
    DwdMosmixParameter.LARGE.WEATHER_SIGNIFICANT_OPTIONAL_LAST_1H,
    DwdMosmixParameter.LARGE.WEATHER_SIGNIFICANT_OPTIONAL_LAST_3H,
    DwdMosmixParameter.LARGE.WEATHER_SIGNIFICANT_OPTIONAL_LAST_6H,
    DwdMosmixParameter.LARGE.WEATHER_SIGNIFICANT_OPTIONAL_LAST_12H,
    DwdMosmixParameter.LARGE.WEATHER_SIGNIFICANT_OPTIONAL_LAST_24H,
    DwdMosmixParameter.LARGE.WEATHER_SIGNIFICANT.value,
    DwdMosmixParameter.LARGE.WEATHER_SIGNIFICANT_LAST_3H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_WIND_GUST_GE_25_KN_LAST_12H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_WIND_GUST_GE_40_KN_LAST_12H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_WIND_GUST_GE_55_KN_LAST_12H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_FOG_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_FOG_LAST_6H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_FOG_LAST_12H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_0_0_MM_LAST_12H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_0_2_MM_LAST_6H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_0_2_MM_LAST_12H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_0_2_MM_LAST_24H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_1_0_MM_LAST_12H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_5_0_MM_LAST_6H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_5_0_MM_LAST_12H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_5_0_MM_LAST_24H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_DRIZZLE_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_STRATIFORM_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_CONVECTIVE_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_THUNDER_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_LIQUID_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_SOLID_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_FREEZING_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_VISIBILITY_BELOW_1000_M.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_0_0_MM_LAST_6H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_0_1_MM_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_0_2_MM_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_0_3_MM_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_0_5_MM_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_0_7_MM_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_1_0_MM_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_2_0_MM_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_SUNSHINE_DURATION_RELATIVE_GT_0_PCT_LAST_24H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_SUNSHINE_DURATION_RELATIVE_GT_30_PCT_LAST_24H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_SUNSHINE_DURATION_RELATIVE_GT_60_PCT_LAST_24H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_RADIATION_GLOBAL_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_3_0_MM_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_5_0_MM_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_10_0_MM_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_10_0_MM_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_15_0_MM_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_25_0_MM_LAST_1H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_STRATIFORM_LAST_6H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_CONVECTIVE_LAST_6H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_THUNDER_LAST_6H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_LAST_6H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_LIQUID_LAST_6H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_FREEZING_LAST_6H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_SOLID_LAST_6H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_DRIZZLE_LAST_6H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_FOG_LAST_24H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_WIND_GUST_GE_25_KN_LAST_6H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_WIND_GUST_GE_40_KN_LAST_6H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_WIND_GUST_GE_55_KN_LAST_6H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_STRATIFORM_LAST_12H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_CONVECTIVE_LAST_12H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_THUNDER_LAST_12H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_LAST_12H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_LIQUID_LAST_12H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_FREEZING_LAST_12H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_SOLID_LAST_12H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_DRIZZLE_LAST_12H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_1_0_MM_LAST_6H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_0_0_MM_LAST_24H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_HEIGHT_GT_1_0_MM_LAST_24H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_PRECIPITATION_LAST_24H.value,
    DwdMosmixParameter.LARGE.PROBABILITY_THUNDER_LAST_24H.value,
}
